@@ -3,7 +3,7 @@ use DB::CouchDB;
 use Moose;
 use Carp;
 
-our $VERSION = '0.3.03';
+our $VERSION = '0.3';
 
 =head1 NAME
 
@@ -11,7 +11,7 @@ our $VERSION = '0.3.03';
 
 =head1 VERSION
 
-0.3.03
+0.2.1
 
 =head1 RATIONALE
 
@@ -89,30 +89,6 @@ sub load_schema_from_db {
     return $self;
 }
 
-=head2 dump_db
-
-dumps the entire db to a file for backup
-
-=cut
-
-#TODO(jwall) tool to dump the whole db to a backup file
-sub dump_whole_db {
-    my $self = shift;
-    my $pretty = shift;
-    my $db = $self->server;
-    #load our schema
-    my $doc_list = $db->all_docs();
-    my @docs;
-    while (my $docname = $doc_list->next_key() ) {
-        my $doc = $db->get_doc($docname);
-        push @docs, $doc;
-    }
-    $db->json->pretty([$pretty]);
-    my $script = $db->json->encode(\@docs);
-    $db->json->pretty([undef]);
-    return $script;
-}
-
 sub _mk_view_accessor {
     my $self = shift;
     my $doc = shift;
@@ -162,7 +138,6 @@ sub _schema_no_revs {
 =head2 dump($pretty)
 
 Returns the database schema as a json string.
-if $pretty is true then the dump will be pretty printed
 
 =cut
 
@@ -177,36 +152,20 @@ sub dump {
     return $script;
 }
 
-
 =head2 push()
 
 Pushes the current schema stored in the object to the database. Used in combination with load_schema_from_script
 you can restore or create databse schemas from a json defintion file.
 
+If $pretty is true then the string will be pretty printed.
+
 =cut
 
 sub push {
-    my $self = shift;
-    my $db = $self->server;
-    for my $doc ( $self->_schema_no_revs() ) {
-        $db->create_named_doc($doc, $doc->{_id});
-    }
-    $self->load_schema_from_db();
-    return $self;
-}
-
-=head2 push_from_script
-
-=cut
-
-sub push_from_script {
     my $self = shift;
     my $script = shift;
     my $db = $self->server;
-    my $docs = $db->json->decode($script);
-    for my $doc ( @$docs ) {
-        delete $doc->{_rev}
-            if $doc->{_rev};
+    for my $doc ( $self->_schema_no_revs() ) {
         $db->create_named_doc($doc, $doc->{_id});
     }
     $self->load_schema_from_db();
@@ -223,60 +182,6 @@ sub get {
     return $self->server->get_doc($name);
 }
 
-=head2 create_doc(%sargs) 
-
-create a doc on the server. accepts the following arguments
-
-    id => 'the name of the document' #optional if you want to let CouchDB name it for you
-    doc => $object #not optional $object is the document to store in CouchDB
-
-=cut
-
-sub create_doc {
-    my $self = shift;
-    my %args = @_;
-    my $db = $self->server;
-    if ( $args{id} ) {
-        my $id = $args{id};
-        return $db->create_named_doc( $args{doc}, $args{id} );
-    } else {
-        return $db->create_doc( $args{doc} );
-    }
-}
-
-=head2 create_new_db(db => 'database name')
-
-create a new database in CouchDB and return a DB::CouchDB::Schema object for it.
-
-It takes the following argument
-   
-   db => 'database name' # not optional the name of the database to create.
-
-=cut
-
-sub create_new_db {
-    my $self = shift;
-    my %args = @_;
-    my $db = $self->server;
-    if ( !$args{db} ) {
-        croak "Must provide a DB to create";
-    }
-    #create a new DB::CouchDB object to represent the server
-    my $srv = DB::CouchDB->new( host => $db->host,
-                                port => $db->port,
-                                db   => $args{db},
-                              );
-    # create the database
-    my $result = $srv->create_db();
-    if ( $result->err ) {
-        croak "Failed to create the DB $args{db}:". $result->errstr;
-    }
-    #create a schema object for the databas and return ite
-    my $schema = DB::CouchDB::Schema->new();
-    $schema->server($srv);
-    return $schema;
-}
-
 =head2 wipe
 
 Wipes the schema from the database. Only deletes the views not data and
@@ -301,5 +206,14 @@ for the views. See L<DB::CouchDB> view method for more information on the args f
 
 =cut
 
+#sub AUTOLOAD {
+#    my ($package, $call) = $AUTOLOAD =~ /^(.+)::(.+)$/;
+#    my $self = shift;
+#    if ($package eq 'DB::CouchDB::Schema') {
+#        if ( exists $self->{views}{$call}) {
+#            return $self->{views}{$call}->(@_);
+#        }
+#    }
+#}
 
 1;
